# Bikeshed Documentation

## Living Standard, 19 December 2025

This version:
  https://speced.github.io/bikeshed/
Issue Tracking:
  GitHub
  Inline In Spec
Editor:
  Tab Atkins-Bittner

To the extent possible under law, the editors have waived all copyright and related or neighboring rights to this work. In addition, as of 19 December 2025, the editors have made this specification available under the Open Web Foundation Agreement Version 1.0, which is available at https://www.openwebfoundation.org/the-agreements/the-owf-1-0-agreements-granted-claims/owfa-1-0. Parts of this work may be from another specification document. If so, those parts are instead covered by the license of that specification document.

## Abstract

Bikeshed is a spec-generating tool that takes in lightly-decorated Markdown and spits out a full spec, with cross-spec autolinking, automatic generation of indexes/ToC/etc, and many other features.

## Conformance

Conformance requirements are expressed with a combination of descriptive assertions and RFC 2119 terminology. The key words “MUST”, “MUST NOT”, “REQUIRED”, “SHALL”, “SHALL NOT”, “SHOULD”, “SHOULD NOT”, “RECOMMENDED”, “MAY”, and “OPTIONAL” in the normative parts of this document are to be interpreted as described in RFC 2119. However, for readability, these words do not appear in all uppercase letters in this specification.

All of the text of this specification is normative except sections explicitly marked as non-normative, examples, and notes. [RFC2119]

Examples in this specification are introduced with the words “for example” or are set apart from the normative text with `class="example"`, like this:

This is an example of an informative example.

Informative notes begin with the word “Note” and are set apart from the normative text with `class="note"`, like this:

Note, this is an informative note.

## Index

### Terms defined by this specification

- [ABSTRACT], in § 5.3.2
- Abstract, in § 4
- Advisement Class, in § 4
- Algorithms, in § 5.8
- And, in § 14.1
- Assertion Class, in § 4
- Assume Explicit For, in § 4
- At Risk, in § 4
- autolink, in § 5.7
- bar(arg1, arg2), in § 9.5
- biblio autolink, in § 7.2
- bikeshed escapes, in § 5.2
- Block Elements, in § 4
- Boilerplate, in § 4
- boolish, in § 4
- C, in § 14.1
- Can I Use URL, in § 4
- Canonical URL, in § 4
- [CDATE], in § 5.3.2
- [CEXPIRES], in § 5.3.2
- Choice, in § 14.1
- Comment, in § 14.1
- Complain About, in § 4
- custom character references, in § 5.2
- [CUSTOMWARNINGTEXT], in § 5.3.2
- Custom Warning Text, in § 4
- [CUSTOMWARNINGTITLE], in § 5.3.2
- Custom Warning Title, in § 4
- Dark Mode, in § 4
- datablock, in § 5.6
- [DATE], in § 5.3.2
- Date, in § 4
- [DATE-DMMY], in § 5.3.2
- [DATE-MMY], in § 5.3.2
- [DATE-MY], in § 5.3.2
- [DEADLINE], in § 5.3.2
- Deadline, in § 4
- Default Biblio Display, in § 4
- Default Highlight, in § 4
- Default Ref Status, in § 4
- dfn autolink, in § 7.1
- Die On, in § 4
- Die When, in § 4
- doctype, in § 4
- doctypes file, in § 4
- ED, in § 4
- Editor, in § 4
- Editor Term, in § 4
- exclude-if, in § 13.2
- [EXPIRES], in § 5.3.2
- Expires, in § 4
- [EXPIRES-DMMY], in § 5.3.2
- [EXPIRES-MMY], in § 5.3.2
- [EXPIRES-MY], in § 5.3.2
- External Infotrees, in § 4
- Favicon, in § 4
- flex-basis, in § 9.2
- Foo, in § 9.5
- Force Crossorigin, in § 4
- Former Editor, in § 4
- Group, in § 4
- H1, in § 4
- [HISTORY], in § 5.3.2
- if-wrapper, in § 13.2
- Ignore Can I Use URL Failure, in § 4
- Ignored Terms, in § 4
- Ignored Vars, in § 4
- Ignore MDN Failure, in § 4
- Image Auto Size, in § 4
- Implementation Report, in § 4
- Include Can I Use Panels, in § 4
- include-if, in § 13.2
- Include MDN Panels, in § 4
- Indent, in § 4
- Infer CSS Dfns, in § 4
- Informative Classes, in § 4
- Inline Github Issues, in § 4
- [ISODATE], in § 5.3.2
- [ISODEADLINE], in § 5.3.2
- [ISOEXPIRES], in § 5.3.2
- Issue Class, in § 4
- Issue Tracker Template, in § 4
- Issue Tracking, in § 4
- l, in § 5.7
- [LATEST], in § 5.3.2
- [LEVEL], in § 5.3.2
- Level, in § 4
- Line Numbers, in § 4
- Link Checker Timeout, in § 4
- Link Defaults, in § 4
- Local Boilerplate, in § 4
- [LOGO], in § 5.3.2
- Logo, in § 4
- [LONGSTATUS], in § 5.3.2
- [MAILINGLIST], in § 5.3.2
- Mailing List, in § 4
- [MAILINGLISTARCHIVES], in § 5.3.2
- Mailing List Archives, in § 4
- manual autolink, in § 7.3
- Markup Shorthands, in § 4
- Max ToC Depth, in § 4
- Metadata Include, in § 4
- Metadata Order, in § 4
- N, in § 14.1
- No Abstract, in § 4
- no-autosize, in § 5.16
- No Editor, in § 4
- NonTerminal, in § 14.1
- Note Class, in § 4
- OneOrMore, in § 14.1
- Opaque Elements, in § 4
- Opt, in § 14.1
- Optional, in § 14.1
- Or, in § 14.1
- Org, in § 4
- pathprefix, in § 12.1
- Plus, in § 14.1
- Prepare For TR, in § 4
- Previous Version, in § 4
- Remove Multiple Links, in § 4
- [REPLACEDBY], in § 5.3.2
- [REPOSITORY], in § 5.3.2
- Repository, in § 4
- [REPOSITORYURL], in § 5.3.2
- Required IDs, in § 4
- Revision, in § 4
- S, in § 14.1
- Seq, in § 14.1
- Sequence, in § 14.1
- [SHORTNAME], in § 5.3.2
- Shortname, in § 4
- Skip, in § 14.1
- skip-existence-check, in § 12.1
- Slim Build Artifact, in § 4
- [SNAPSHOTID], in § 5.3.2
- [SNAPSHOTURL], in § 5.3.2
- soft boolish, in § 4
- [SPECTITLE], in § 5.3.2
- Stack, in § 14.1
- Star, in § 14.1
- [STATUS], in § 5.3.2
- Status, in § 4
- [STATUSTEXT], in § 5.3.2
- Status Text, in § 4
- T, in § 14.1
- Terminal, in § 14.1
- Test Suite, in § 4
- Text Macro, in § 4
- [TITLE], in § 5.3.2
- Title, in § 4
- Toggle Diffs, in § 4
- TR, in § 4
- Tracking Vector Alt Text, in § 4
- Tracking Vector Class, in § 4
- Tracking Vector Image, in § 4
- Tracking Vector Image Height, in § 4
- Tracking Vector Image Width, in § 4
- Tracking Vector Title, in § 4
- Translate IDs, in § 4
- Translation, in § 4
- URL, in § 4
- Use Dfn Panels, in § 4
- Use <i> Autolinks, in § 4
- [VERSION], in § 5.3.2
- [VSHORTNAME], in § 5.3.2
- [W3C-STATUS-URL], in § 5.3.2
- [W3C-STYLESHEET-URL], in § 5.3.2
- Warning, in § 4
- [WORKSTATUS], in § 5.3.2
- Work Status, in § 4
- wpt, in § 12
- WPT Display, in § 4
- WPT Path Prefix, in § 4
- wpt-rest, in § 12.1
- [YEAR], in § 5.3.2
- ZeroOrMore, in § 14.1

### Terms defined by reference

- [CSS-FLEXBOX-1] defines the following terms:
  - flex container
  - flex item
  - main size
- [CSS-LOGICAL-1] defines the following terms:
  - logical property group
- [HTML] defines the following terms:
  - a
  - audio
  - body
  - code
  - dd
  - del
  - dfn
  - dir
  - dl
  - dt
  - h1
  - h2
  - h6
  - head
  - height
  - hidden
  - i
  - image source
  - img
  - input
  - lang
  - link
  - pixel density descriptor
  - pre
  - script
  - span
  - src
  - srcset
  - style
  - table
  - title
  - title (for html-global)
  - var
  - video
  - width
  - xmp
- [INFRA] defines the following terms:
  - list
  - map
  - tracking vector
- [SVG2] defines the following terms:
  - svg
- [WEB-ANIMATIONS-1] defines the following terms:
  - animation type
- [WEBIDL] defines the following terms:
  - DOMString
  - long
  - undefined

## References

### Normative References

[CSS-FLEXBOX-1]
  Elika Etemad; Tab Atkins Jr.; Rossen Atanassov. CSS Flexible Box Layout Module Level 1. URL: https://drafts.csswg.org/css-flexbox/
[CSS-LOGICAL-1]
  Elika Etemad; Rossen Atanassov. CSS Logical Properties and Values Module Level 1. URL: https://drafts.csswg.org/css-logical-1/
[CSS-VALUES-4]
  Tab Atkins Jr.; Elika Etemad. CSS Values and Units Module Level 4. URL: https://drafts.csswg.org/css-values-4/
[HTML]
  Anne van Kesteren; et al. HTML Standard. Living Standard. URL: https://html.spec.whatwg.org/multipage/
[INFRA]
  Anne van Kesteren; Domenic Denicola. Infra Standard. Living Standard. URL: https://infra.spec.whatwg.org/
[RFC2119]
  S. Bradner. Key words for use in RFCs to Indicate Requirement Levels. March 1997. Best Current Practice. URL: https://datatracker.ietf.org/doc/html/rfc2119
[RFC8610]
  H. Birkholz; C. Vigano; C. Bormann. Concise Data Definition Language (CDDL): A Notational Convention to Express Concise Binary Object Representation (CBOR) and JSON Data Structures. June 2019. Proposed Standard. URL: https://www.rfc-editor.org/rfc/rfc8610
[SVG2]
  Amelia Bellamy-Royds; et al. Scalable Vector Graphics (SVG) 2. URL: https://svgwg.org/svg2-draft/
[WEB-ANIMATIONS-1]
  Brian Birtles; et al. Web Animations. URL: https://drafts.csswg.org/web-animations-1/
[WEBIDL]
  Edgar Chen; Timothy Gu. Web IDL Standard. Living Standard. URL: https://webidl.spec.whatwg.org/

## Property Index

Name | Value | Initial | Applies to | Inh. | %ages | Animation type | Canonical order | Computed value
--- | --- | --- | --- | --- | --- | --- | --- | ---
flex-basis | content | <<'width'>> | auto | flex items | no | relative to the flex container’s inner main size | length | per grammar | as specified, with lengths made absolute

## IDL Index

    interface Foo {
      undefined bar(long arg1, DOMString? arg2);
    };

## Issues Index

Define the issues-list format. The `-t` output is already more than enough to actually work with, but it would still be good to describe it more fully. ↵
This will generate a link to the specified issue at the end of the issue paragraph, like this. [Issue #1532] ↵
fill in ↵